MatcherBuilder

Struct MatcherBuilder 

pub struct MatcherBuilder<'a, T: Matchable> { /* private fields */ }
A builder for creating matchers with a fluent API

Example

use condition_matcher::{MatcherBuilder, MatcherMode, ConditionOperator, Matcher};

let matcher = MatcherBuilder::<i32>::new()
    .mode(MatcherMode::AND)
    .value_equals(42)
    .build();

assert!(matcher.matches(&42));

Implementations

Source

impl<'a, T: Matchable + 'static> MatcherBuilder<'a, T>

pub fn new() -> Self

Create a new builder with default AND mode

pub fn mode(self, mode: ConditionMode) -> Self

Set the matching mode

pub fn value_equals(self, expected: T) -> Self

Add a condition that the value equals the expected value

pub fn value_not_equals(self, expected: T) -> Self

Add a condition that the value does not equal the expected value

pub fn length(self, len: usize, operator: ConditionOperator) -> Self

Add a length condition

pub fn length_equals(self, len: usize) -> Self

Add a condition that length equals the expected value

pub fn length_gte(self, len: usize) -> Self

Add a condition that length is greater than or equal to the expected value

pub fn length_lte(self, len: usize) -> Self

Add a condition that length is less than or equal to the expected value

pub fn condition(self, condition: Condition<'a, T>) -> Self

Add a raw condition

pub fn build(self) -> RuleMatcher<'a, T>

Build the matcher